﻿/*
 * Copyright 2009-11 Williams Technologies Limtied.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Kajbity is a trademark of Williams Technologies Limited.
 *
 * http://www.kajabity.com
 */
using System;
using System.IO;
using System.Xml.Serialization;
using System.Diagnostics;

using Kajabity.Tools.Forms;

namespace Event_Manager
{
    /// <summary>
    /// Handles loading and saving Event Documents.
    /// </summary>
    public class EventDocumentManager : DocumentManager
    {

        public EventDocument EventDocument
        {
            get
            {
                return (EventDocument) document;
            }
        }

        public EventDocumentManager()
        {
            DefaultName = "events";
            DefaultExtension = "xml";
        }

        public override void NewDocument()
        {
            document = new EventDocument();

            base.NewDocument();
        }

        public override void Load( string filename )
        {
            Debug.WriteLine( "Loading " + filename );

            TextReader reader = new StreamReader( filename );
            XmlSerializer serialiser = new XmlSerializer( typeof( EventDocument ) );
            document = (EventDocument) serialiser.Deserialize( reader );
            reader.Close();

            Debug.WriteLine( "Loaded " + ((EventDocument) document).Events.Count + " events." );

            base.Load( filename );
        }

        public override void Save( string filename )
        {
            XmlSerializer serialiser = new XmlSerializer( typeof( EventDocument ) );
            TextWriter writer = new StreamWriter( filename );
            serialiser.Serialize( writer, document );
            writer.Close();

            base.Save( filename );
        }
    }
}
