﻿/*
 * Copyright 2009-11 Williams Technologies Limtied.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Kajbity is a trademark of Williams Technologies Limited.
 *
 * http://www.kajabity.com
 */
using System;
using System.Collections;
using System.Drawing;
using System.Windows.Forms;
using System.Text;
using System.Diagnostics;

using Kajabity.Tools.Forms;

namespace Event_Manager
{
	/// <summary>
	/// Description of MainForm.
	/// </summary>
	public partial class MainForm : SDIForm
	{
		public MainForm()
			: base( new EventDocumentManager() )
		{
			//
			// The InitializeComponent() call is required for Windows Forms designer support.
			//
			InitializeComponent();
		}
		
		public override void DocumentChanged()
		{
			// Clear the list.
			this.listThistleEvents.Items.Clear();

			if( manager.Opened )
			{
				//	Update main form heading.
				this.Text = Application.ProductName + " - " + manager.Document.Name;

				ArrayList months = ((EventDocument) manager.Document).Events;

				//	Update the content window.
				foreach( ThistleEventMonth month in months )
				{
					foreach( ThistleEvent thistleEvent in month.ThistleEvents )
					{
						InsertThistleEvent( -1, thistleEvent );

//						Debug.WriteLine(
//							"T:" + XmlUtils.ToString( thistleEvent.Title ) + ", " +
//							"S:" + XmlUtils.ToShortDateString( thistleEvent.EventDate ) + " " + thistleEvent.EventTime + ", " +
//							"E:" + XmlUtils.ToShortDateString( thistleEvent.EventDateTo ) + " " + thistleEvent.EventTimeTo + ", " +
//							"L:" + thistleEvent.Location + ", " +
//							"C:" + thistleEvent.Category + ", " +
//							"D:" + XmlUtils.ToString( thistleEvent.Description ) + ", " +
//							"G:" + thistleEvent.Group + ", " +
//							"H:" + thistleEvent.Home + ", " +
//							"P:" + XmlUtils.ToString( thistleEvent.Program ) );
					}
				}
			}
			else
			{
				//	Update main form heading.
				this.Text = Application.ProductName;
			}

			//	Force a display update.
			this.Refresh();
		}

		private void InsertThistleEvent( int index, ThistleEvent thistleEvent )
		{
			String label = "";
			if( thistleEvent.EventDate.HasValue )
			{
				label = thistleEvent.EventDate.Value.ToShortDateString();
			}
			if( thistleEvent.EventDateTo.HasValue )
			{
				label = label + "-" + thistleEvent.EventDateTo.Value.ToShortDateString();
			}

			ListViewItem item = new ListViewItem( label );

			item.Checked = thistleEvent.Home;
			
			item.SubItems.Add( new ListViewItem.ListViewSubItem( item, XmlUtils.ToString( thistleEvent.Title ) ) );
			item.SubItems.Add( new ListViewItem.ListViewSubItem( item, thistleEvent.Category ) );
			item.SubItems.Add( new ListViewItem.ListViewSubItem( item, thistleEvent.Group ) );
			item.SubItems.Add( new ListViewItem.ListViewSubItem( item, thistleEvent.Location ) );

			if( index < 0 )
			{
				listThistleEvents.Items.Add( item );
			}
			else
			{
				listThistleEvents.Items.Insert( index, item );
			}
		}

		private bool doThistleEventDialog( ThistleEvent thistleEvent )
		{
			ThistleEventDialog dialog = new ThistleEventDialog();
			dialog.StartDate = thistleEvent.EventDate.Value;
			dialog.Title = XmlUtils.ToString( thistleEvent.Title );
			dialog.Description = XmlUtils.ToString( thistleEvent.Description );
			
			DialogResult result = dialog.ShowDialog( this );
			if( result == DialogResult.OK )
			{
				thistleEvent.Title = XmlUtils.FromString( dialog.Title );
				thistleEvent.EventDate = dialog.StartDate;
				thistleEvent.Description = XmlUtils.FromString( dialog.Description );
				return true;
			}
			else
			{
				return false;
			}
		}

		void ListThistleEventsItemActivate(object sender, EventArgs e)
		{
			if( listThistleEvents.SelectedItems.Count > 0 )
			{
				int index = listThistleEvents.SelectedIndices[ 0 ];
				ThistleEvent thistleEvent = ((EventDocument) manager.Document).GetAt( index );

				if( doThistleEventDialog( thistleEvent ) )
				{
					listThistleEvents.Items.RemoveAt( index );
					((EventDocument) manager.Document).RemoveAt( index );
					
					InsertThistleEvent( index, thistleEvent );
				}
			}
		}

		void PrintToolStripMenuItemClick(object sender, EventArgs e)
		{
		}
		
		void ListCalendarToolStripMenuItemClick(object sender, EventArgs e)
		{
			GoogleCalendarUtils.DumpCalendar();
		}
		
		void InsertEntryToolStripMenuItemClick(object sender, EventArgs e)
		{
			if( manager != null && manager.Document != null )
			{
				GoogleCalendarUtils utils = new GoogleCalendarUtils();
				ArrayList months = ((EventDocument) manager.Document).Events;

				//	Update the content window.
				foreach( ThistleEventMonth month in months )
				{
					foreach( ThistleEvent thistleEvent in month.ThistleEvents )
					{
						utils.InsertEntry( thistleEvent );
					}
				}
			}
		}
	}
}
